@@ -2,13 +2,13 @@ options("RprobitB_progress" = FALSE)
 
 test_that("computing model selection criteria works", {
   set.seed(1)
-  data("Train", package = "mlogit")
-  Train$price_A <- Train$price_A / 100 * 2.20371
-  Train$price_B <- Train$price_B / 100 * 2.20371
-  Train$time_A <- Train$time_A / 60
-  Train$time_B <- Train$time_B / 60
   form <- choice ~ price + time + change + comfort | 0
-  data <- prepare_data(form = form, choice_data = Train)
+  data <- prepare_data(
+    form = form,
+    choice_data = train_choice,
+    id = "deciderID",
+    idc = "occasionID"
+  )
   model_train <- fit_model(
     data = data,
     scale = "price := -1",
